==> assertj-build-3.25.3.tar.gz: assertj-assertj-build-3.25.3/assertj-core/src/test/java/org/assertj/core/api/short2darray/Short2DArrayAssert_usingCustomComparator_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2024 the original author or authors.
 */
package org.assertj.core.api.short2darray;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.test.AlwaysEqualComparator.alwaysEqual;

import org.assertj.core.api.Short2DArrayAssert;
import org.assertj.core.api.Short2DArrayAssertBaseTest;
import org.assertj.core.test.AlwaysEqualComparator;
import org.junit.jupiter.api.Test;

class Short2DArrayAssert_usingCustomComparator_Test extends Short2DArrayAssertBaseTest {

  private static final AlwaysEqualComparator<short[][]> ALWAYS_EQUAL = alwaysEqual();

  @Override
  protected Short2DArrayAssert invoke_api_method() {
    return assertions.usingComparator(ALWAYS_EQUAL);
  }

  @Override
  protected void verify_internal_effects() {
    assertThat(getObjects(assertions).getComparator()).isSameAs(ALWAYS_EQUAL);
  }

  @Test
  void should_honor_comparator() {
    assertThat(new short[][] {}).usingComparator(ALWAYS_EQUAL)
                                .isEqualTo(new short[][] { { 1, 2 }, { 3, 4 } });
  }

}

==> assertj-build-3.27.6.tar.gz: assertj-assertj-build-3.27.6/assertj-core/src/test/java/org/assertj/core/api/short2darray/Short2DArrayAssert_usingCustomComparator_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2025 the original author or authors.
 */
package org.assertj.core.api.short2darray;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.testkit.AlwaysEqualComparator.alwaysEqual;

import org.assertj.core.api.Short2DArrayAssert;
import org.assertj.core.api.Short2DArrayAssertBaseTest;
import org.assertj.core.testkit.AlwaysEqualComparator;
import org.junit.jupiter.api.Test;

class Short2DArrayAssert_usingCustomComparator_Test extends Short2DArrayAssertBaseTest {

  private static final AlwaysEqualComparator<short[][]> ALWAYS_EQUAL = alwaysEqual();

  @Override
  protected Short2DArrayAssert invoke_api_method() {
    return assertions.usingComparator(ALWAYS_EQUAL);
  }

  @Override
  protected void verify_internal_effects() {
    assertThat(getObjects(assertions).getComparator()).isSameAs(ALWAYS_EQUAL);
  }

  @Test
  void should_honor_comparator() {
    assertThat(new short[][] {}).usingComparator(ALWAYS_EQUAL)
                                .isEqualTo(new short[][] { { 1, 2 }, { 3, 4 } });
  }

}
